pub enum DomainClassification {
Domain(Name, Option<u16>),
Literal(HostOrSocketAddress),
}Expand description
Helper to reason about a domain name string. It can either be name that needs to be resolved, or some kind of IP literal. We also allow for an optional port number to be present in the domain name string.
Variants
Domain(Name, Option<u16>)
A DNS Name pending resolution, plus an optional port number
Literal(HostOrSocketAddress)
A literal IP address (no port), or socket address (with port)
Implementations